Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1314)

Unified Diff: scripts/tools/actions_parser.py

Issue 2084383003: Move 'buildbot.tac' and 'buildbot' files to a common directory. (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/build.git@master
Patch Set: Rebase Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « masters/state-template.txt ('k') | scripts/tools/buildbot_tool_templates/buildbot » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: scripts/tools/actions_parser.py
diff --git a/scripts/tools/actions_parser.py b/scripts/tools/actions_parser.py
index 01e94176f9f8ee2ea301762d9203a88cf3bafd32..1f0d4644c798543f4fdf2a596255828be7dede25 100755
--- a/scripts/tools/actions_parser.py
+++ b/scripts/tools/actions_parser.py
@@ -173,8 +173,8 @@ def get_master(checkout_root, name):
if not name.startswith('master.'):
name = 'master.%s' % (name,)
- # Identify masters as directories containing 'buildbot.tac' files.
- glob_path = os.path.join(checkout_root, '*', 'masters', name, 'buildbot.tac')
+ # Identify masters as directories containing 'master.cfg' files.
+ glob_path = os.path.join(checkout_root, '*', 'masters', name, 'master.cfg')
for candidate in glob.iglob(glob_path):
return Master.fromdir(os.path.split(candidate)[0])
return None
@@ -184,8 +184,8 @@ def get_all_masters(checkout_root):
"""Identifies all Master instances by probing a checkout root."""
masters = []
- # Identify masters as directories containing 'buildbot.tac' files.
- glob_path = os.path.join(checkout_root, '*', 'masters', '*', 'buildbot.tac')
+ # Identify masters as directories containing 'master.cfg' files.
+ glob_path = os.path.join(checkout_root, '*', 'masters', '*', 'master.cfg')
for candidate in glob.iglob(glob_path):
master = Master.fromdir(os.path.split(candidate)[0])
« no previous file with comments | « masters/state-template.txt ('k') | scripts/tools/buildbot_tool_templates/buildbot » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698